# Woclema - Weblog, Originally Command Line Editable/Manageable
# Copyright (C) 2007 Tommi Saviranta  <wnd@iki.fi>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


package Woclema::Link;

use strict;
use warnings FATAL => 'all';
use diagnostics;

use Time::Local;

use Woclema::Config;


=item url
Attach baseurl if defined.

0: URL
r: URL
=cut
sub url($) {
	my ($url) = @_;
	print "?" unless defined($url);

	if (defined($Woclema::Config::base_url)) {
		$_ = $Woclema::Config::base_url . "/$url";
		s/([^:])\/\/+/$1\//g;
		return $_;
	} else {
		return $url;
	}
}


=item entry
Permanent link to entry.

0: entry ID
1: anchor
r: URL
=cut
sub entry($$) {
	my ($t, $a) = @_;

	return "?" unless defined($t);
	$a = defined($a) ? "#$a" : "";

	if ($Woclema::Config::rewrite == 1) {
		return &url("entry-$t") . $a;
	} elsif ($Woclema::Config::rewrite == 2) {
		return &url("entry/$t") . $a;
	} else {
		return &url("?entry=$t") . $a;
	}
}


=item day
Link to day.

0: day (epoch)
r: URL
=cut
sub day($) {
	my ($t) = @_;

	return "?" unless defined($t);

	# Get unified timestamp for day
	my @date = gmtime($t);
	$t = timegm(0, 0, 0, $date[3], $date[4], $date[5] + 1900);

	if ($Woclema::Config::rewrite == 1) {
		return &url("day-$t");
	} elsif ($Woclema::Config::rewrite == 2) {
		return &url("day/$t");
	} else {
		return "?day=$t";
	}
}


=item month
Link to month.

0: month (epoch)
r: URL
=cut
sub month($) {
	my ($t) = @_;

	return "?" unless defined($t);

	# Get unified timestamp for month
	my @date = gmtime($t);
	$t = timegm(0, 0, 0, 1, $date[4], $date[5] + 1900);

	if ($Woclema::Config::rewrite == 1) {
		return &url("month-$t");
	} elsif ($Woclema::Config::rewrite == 2) {
		return &url("month/$t");
	} else {
		return "?month=$t";
	}
}


=item all_time_summary
Link to posts per month -summary.

r: URL
=cut
sub summary() {
	if ($Woclema::Config::rewrite == 1) {
		return &url("summary");
	} elsif ($Woclema::Config::rewrite == 2) {
		return &url("summary");
	} else {
		return "?summary";
	}
}


=item category
Link to category.

0: category ID
r: URL
=cut
sub category($) {
	my ($t) = @_;

	return "?" unless defined($t);

	if ($Woclema::Config::rewrite == 1) {
		return &url("category-$t");
	} elsif ($Woclema::Config::rewrite == 2) {
		return &url("category/$t");
	} else {
		return "?cat=$t";
	}
}


return 1;
